/*

  Copyright (C) 2020 willipink.eu
  Author Moritz Münch moritzmuench@mailbox.org

  This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 3 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program. If not, see <http://www.gnu.org/licenses/>. */


import { Cookie } from './modules/cookie.mjs';


$(document).ready(function() {

  //
  // Options
  //

  let settings = {
    found:        true,
    found_by:     '',
    found_on:     '',
    circulation:  '',
    buy_only:     false,
    checked:      false,
    ec:           false,
    exists:       true
  }

  // button #advanced_options
  $('#show_advanced_options').click(function() {
    $('#advanced_options').slideToggle();
  });

  // checkbox #exists
  $('input#exists').change(function() {

    if (this.checked === true) {

      // save settings
      settings['circulation'] = $('#circulation').val();
      let checkboxes = $('#found_now, #found, #buy_only, #checked, #ec')
        .map(function() {
          return {
            [$(this).prop('id')]: $(this).prop('checked')
          }
        }).get();
      for (let box of checkboxes) {
        for (let item in box) { settings[item] = box[item]; }
      }

      // disable settings
      $('#circulation').val('Auflage');
      $('#found, #buy_only, #checked, #ec').each(function() {
        $(this).prop('checked', false);
      });
      $('#found, #select_usernames, #circulation, #buy_only, #checked, #ec').each(function() {
        $(this).prop('disabled', 'disabled');
      });

    // checkbox #exists not checked
    } else {

      // restore settings
      $('#circulation').val(settings['circulation']);
      $('#found_now, #found, #buy_only, #checked, #ec').each(function() {
        let setting = $(this).prop('id');
        $(this).prop('checked', settings[setting]);
      });

      // enable settings
      $('#found, #select_usernames, #circulation, #buy_only, #checked, #ec').each(function() {
        $(this).prop('disabled', '');
      });

    }
  });


  // datepicker TODO make it nicer
  $.datepicker.setDefaults( $.datepicker.regional['de'] );
  $('input[name=datetime]').datepicker({
    defaultDate: new Date(),
    dateFormat: 'dd.mm.yy'
  });

  function render_login(input_name, input_color) {
    // manage user login

    let color = decodeURIComponent(input_color);
    let name = decodeURIComponent(input_name);
    new Cookie('coinc-name', name)

    render_login_color(color);
    let option = $('div#controlbar option[value=' + name + ']');
    if (option.length == 0) {
      $('div#controlbar select').append($('<option>', {
        value: name, color: color, html: name
      }));
    }

    $('div#controlbar option[value=' + name + ']').attr('selected', 'selected');
  }


  function render_login_color(color) {
    // manage login colors

    new Cookie('coinc-color', color);
    $('div#controlbar').css('background-color', color);
  }


  function hide_modal() {
    $('div#modal_add_user').fadeOut('fast');
  }


  // select username on change
  $('div#controlbar select').on('change', function() {
    let color = $('div#controlbar option[value=' + this.value + ']').attr('color');
    $('div#controlbar option[selected=selected]').removeAttr('selected');
    render_login(this.value, color);
  });


  $('button#show_add_user').click(function() {
    $('div#modal_add_user').fadeIn('fast');

    $(document).on('click', function(event) {
      if ($('div#modal_add_user').is(':visible')) {
        let target = $(event.target);
        if (target.attr('id') === 'modal_add_user') {
          hide_modal();
        }
      }
    });

    $(document).keypress(function(event) {
      if (event.keyCode == 27) { // ESC is pressed
        hide_modal();
        $(document).off('keypress');
      }
    });

    $('button#close_modal_add_user').click(function() {
      hide_modal();
    });

    $('button#add_user').click(function() {

      let name = encodeURIComponent($('input#text_user').val());
      let color = encodeURIComponent($('input#text_color').val());

      $.ajax({
        type: 'GET',
        dataType: 'json',
        url: 'add/user/' + name + '/color/' + color,
        success: function(response) {

          if (response.status === 0) {
            $('span#response').fadeOut('fast');
            hide_modal();
            render_login(name, color);

          } else {
            $('span#response').html(response.message);
            $('span#response').css('color', 'red');
          }
        }
      });
    });

  });

  let cookie = new Cookie();
  let name = cookie.get('coinc-name');
  let color = cookie.get('coinc-color');

  if (name != '') {
    render_login(name, color);
  } else {
  //#TODO log in as default if any
  }
});
